about summary refs log tree commit diff
diff options
context:
space:
mode:
authorRicardo Fernández Serrata <76864299+Rudxain@users.noreply.github.com>2024-06-20 02:15:23 -0400
committerrudxain <rudxain@localhost.localdomain>2024-06-24 03:57:55 -0400
commitcfccdbb1641289e92d414b01f67c6a22b485a327 (patch)
treecd07ee107644fb600f366cfe2521a3d1c4c0f8bc
parent32374a196dad3965342e29ca69a59e03efed6271 (diff)
downloadrust-cfccdbb1641289e92d414b01f67c6a22b485a327.tar.gz
rust-cfccdbb1641289e92d414b01f67c6a22b485a327.zip
Clarify that `modulo_one` only applies to ints
-rw-r--r--clippy_lints/src/operators/mod.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/clippy_lints/src/operators/mod.rs b/clippy_lints/src/operators/mod.rs
index 48a442705b2..52dc12fe51e 100644
--- a/clippy_lints/src/operators/mod.rs
+++ b/clippy_lints/src/operators/mod.rs
@@ -627,7 +627,7 @@ declare_clippy_lint! {
 
 declare_clippy_lint! {
     /// ### What it does
     /// Checks for getting the remainder of a division by one or minus
     /// one.
     ///
     /// ### Why is this bad?
@@ -646,7 +646,7 @@ declare_clippy_lint! {
     #[clippy::version = "pre 1.29.0"]
     pub MODULO_ONE,
     correctness,
-    "taking a number modulo +/-1, which can either panic/overflow or always returns 0"
+    "taking an integer modulo +/-1, which can either panic/overflow or always returns 0"
 }
 
 declare_clippy_lint! {
@@ -627,7 +627,7 @@ declare_clippy_lint! {
 declare_clippy_lint! {
     /// ### What it does
-    /// Checks for getting the remainder of a division by one or minus
+    /// Checks for getting the remainder of integer division by one or minus
     /// one.
     ///